ArrayAsRef

Trait ArrayAsRef 

pub trait ArrayAsRef<'a>: Array
where <Self as Array>::Item: 'a,
{ type AsRef: Array<Item = &'a <Self as Array>::Item>; type AsMut: Array<Item = &'a mut <Self as Array>::Item>; // Required methods fn as_ref_array(&'a self) -> Self::AsRef; fn as_mut_array(&'a mut self) -> Self::AsMut; }
Trait for conversation between &[T; N] and [&T; N] (or &mut [T; N] and [&mut T; N])

Required Associated Types

type AsRef: Array<Item = &'a <Self as Array>::Item>

Result of the ‘shared’ conversation, in other words [&T; N] (where T = Self::Item, N = Self::Size)

type AsMut: Array<Item = &'a mut <Self as Array>::Item>

Result of the ‘unique’ conversation, in other words [&mut T; N] (where T = Self::Item, N = Self::Size)

Required Methods

fn as_ref_array(&'a self) -> Self::AsRef

Convert &self to [&T; N] (where T = Self::Item, N = Self::Size)

Examples
use arraylib::ArrayAsRef;

let arr = [0, 1, 2, 3];
let ref_arr = arr.as_ref_array();
assert_eq!(ref_arr, [&0, &1, &2, &3]);
assert_eq!(arr, [0, 1, 2, 3]);
use arraylib::{ArrayAsRef, ArrayExt};

// Don't do like this, it's just an example
fn index_of<A>(a: &A, x: A::Item) -> Option<usize>
where
    for<'a> A: ArrayAsRef<'a>,
    A::Item: PartialEq,
{
    a.as_ref_array()
        .iter_move()
        .enumerate()
        .find(|&(_, it)| it == &x)
        .map(|(idx, _)| idx)
}

let arr = [-2, 1, -1, 2];
assert_eq!(index_of(&arr, 1), Some(1));
assert_eq!(index_of(&arr, 2), Some(3));
assert_eq!(index_of(&arr, 0), None);

NOTE: it’s nighly recommended to use iterators when you need to perform more that one operation (e.g. map + as_ref) because iterators are lazy and ArrayAsRef isn’t.

See also: as_mut_array

fn as_mut_array(&'a mut self) -> Self::AsMut

Convert &mut self to [&mut T; N] (where T = Self::Item, N = Self::Size)

Examples
use arraylib::ArrayAsRef;

let mut arr = [0, 1, 2, 3];
let ref_arr = arr.as_mut_array();
assert_eq!(ref_arr, [&mut 0, &mut 1, &mut 2, &mut 3]);
assert_eq!(arr, [0, 1, 2, 3]);
use arraylib::{ArrayAsRef, ArrayExt};

// Don't do like this, it's just an example
fn find_and_replace<A>(a: &mut A, find: &A::Item, replace: A::Item) -> A::Item
where
    for<'a> A: ArrayAsRef<'a>,
    A::Item: PartialEq,
{
    let mut x = a.as_mut_array().iter_move().find(|it| it == &find);
    match x {
        Some(ref mut inner) => core::mem::replace(inner, replace),
        None => replace,
    }
}

let mut arr = [-2, 1, -1, 2];
assert_eq!(find_and_replace(&mut arr, &1, 8), 1);
assert_eq!(arr, [-2, 8, -1, 2]);

NOTE: it’s nighly recommended to use iterators when you need to perform more that one operation (e.g. map + as_ref) because iterators are lazy and ArrayAsRef isn’t.

See also: as_ref_array

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 0]

Source

type AsMut = [&'a mut T; 0]

Source

type AsRef = [&'a T; 0]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 1]

Source

type AsMut = [&'a mut T; 1]

Source

type AsRef = [&'a T; 1]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 2]

Source

type AsMut = [&'a mut T; 2]

Source

type AsRef = [&'a T; 2]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 3]

Source

type AsMut = [&'a mut T; 3]

Source

type AsRef = [&'a T; 3]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 4]

Source

type AsMut = [&'a mut T; 4]

Source

type AsRef = [&'a T; 4]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 5]

Source

type AsMut = [&'a mut T; 5]

Source

type AsRef = [&'a T; 5]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 6]

Source

type AsMut = [&'a mut T; 6]

Source

type AsRef = [&'a T; 6]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 7]

Source

type AsMut = [&'a mut T; 7]

Source

type AsRef = [&'a T; 7]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 8]

Source

type AsMut = [&'a mut T; 8]

Source

type AsRef = [&'a T; 8]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 9]

Source

type AsMut = [&'a mut T; 9]

Source

type AsRef = [&'a T; 9]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 10]

Source

type AsMut = [&'a mut T; 10]

Source

type AsRef = [&'a T; 10]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 11]

Source

type AsMut = [&'a mut T; 11]

Source

type AsRef = [&'a T; 11]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 12]

Source

type AsMut = [&'a mut T; 12]

Source

type AsRef = [&'a T; 12]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 13]

Source

type AsMut = [&'a mut T; 13]

Source

type AsRef = [&'a T; 13]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 14]

Source

type AsMut = [&'a mut T; 14]

Source

type AsRef = [&'a T; 14]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 15]

Source

type AsMut = [&'a mut T; 15]

Source

type AsRef = [&'a T; 15]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 16]

Source

type AsMut = [&'a mut T; 16]

Source

type AsRef = [&'a T; 16]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 17]

Source

type AsMut = [&'a mut T; 17]

Source

type AsRef = [&'a T; 17]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 18]

Source

type AsMut = [&'a mut T; 18]

Source

type AsRef = [&'a T; 18]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 19]

Source

type AsMut = [&'a mut T; 19]

Source

type AsRef = [&'a T; 19]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 20]

Source

type AsMut = [&'a mut T; 20]

Source

type AsRef = [&'a T; 20]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 21]

Source

type AsMut = [&'a mut T; 21]

Source

type AsRef = [&'a T; 21]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 22]

Source

type AsMut = [&'a mut T; 22]

Source

type AsRef = [&'a T; 22]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 23]

Source

type AsMut = [&'a mut T; 23]

Source

type AsRef = [&'a T; 23]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 24]

Source

type AsMut = [&'a mut T; 24]

Source

type AsRef = [&'a T; 24]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 25]

Source

type AsMut = [&'a mut T; 25]

Source

type AsRef = [&'a T; 25]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 26]

Source

type AsMut = [&'a mut T; 26]

Source

type AsRef = [&'a T; 26]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 27]

Source

type AsMut = [&'a mut T; 27]

Source

type AsRef = [&'a T; 27]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 28]

Source

type AsMut = [&'a mut T; 28]

Source

type AsRef = [&'a T; 28]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 29]

Source

type AsMut = [&'a mut T; 29]

Source

type AsRef = [&'a T; 29]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 30]

Source

type AsMut = [&'a mut T; 30]

Source

type AsRef = [&'a T; 30]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 31]

Source

type AsMut = [&'a mut T; 31]

Source

type AsRef = [&'a T; 31]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 32]

Source

type AsMut = [&'a mut T; 32]

Source

type AsRef = [&'a T; 32]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 33]

Source

type AsMut = [&'a mut T; 33]

Source

type AsRef = [&'a T; 33]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 34]

Source

type AsMut = [&'a mut T; 34]

Source

type AsRef = [&'a T; 34]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 35]

Source

type AsMut = [&'a mut T; 35]

Source

type AsRef = [&'a T; 35]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 36]

Source

type AsMut = [&'a mut T; 36]

Source

type AsRef = [&'a T; 36]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 37]

Source

type AsMut = [&'a mut T; 37]

Source

type AsRef = [&'a T; 37]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 38]

Source

type AsMut = [&'a mut T; 38]

Source

type AsRef = [&'a T; 38]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 39]

Source

type AsMut = [&'a mut T; 39]

Source

type AsRef = [&'a T; 39]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 40]

Source

type AsMut = [&'a mut T; 40]

Source

type AsRef = [&'a T; 40]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 41]

Source

type AsMut = [&'a mut T; 41]

Source

type AsRef = [&'a T; 41]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 42]

Source

type AsMut = [&'a mut T; 42]

Source

type AsRef = [&'a T; 42]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 43]

Source

type AsMut = [&'a mut T; 43]

Source

type AsRef = [&'a T; 43]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 44]

Source

type AsMut = [&'a mut T; 44]

Source

type AsRef = [&'a T; 44]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 45]

Source

type AsMut = [&'a mut T; 45]

Source

type AsRef = [&'a T; 45]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 46]

Source

type AsMut = [&'a mut T; 46]

Source

type AsRef = [&'a T; 46]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 47]

Source

type AsMut = [&'a mut T; 47]

Source

type AsRef = [&'a T; 47]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 48]

Source

type AsMut = [&'a mut T; 48]

Source

type AsRef = [&'a T; 48]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 49]

Source

type AsMut = [&'a mut T; 49]

Source

type AsRef = [&'a T; 49]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 50]

Source

type AsMut = [&'a mut T; 50]

Source

type AsRef = [&'a T; 50]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 51]

Source

type AsMut = [&'a mut T; 51]

Source

type AsRef = [&'a T; 51]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 52]

Source

type AsMut = [&'a mut T; 52]

Source

type AsRef = [&'a T; 52]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 53]

Source

type AsMut = [&'a mut T; 53]

Source

type AsRef = [&'a T; 53]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 54]

Source

type AsMut = [&'a mut T; 54]

Source

type AsRef = [&'a T; 54]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 55]

Source

type AsMut = [&'a mut T; 55]

Source

type AsRef = [&'a T; 55]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 56]

Source

type AsMut = [&'a mut T; 56]

Source

type AsRef = [&'a T; 56]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 57]

Source

type AsMut = [&'a mut T; 57]

Source

type AsRef = [&'a T; 57]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 58]

Source

type AsMut = [&'a mut T; 58]

Source

type AsRef = [&'a T; 58]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 59]

Source

type AsMut = [&'a mut T; 59]

Source

type AsRef = [&'a T; 59]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 60]

Source

type AsMut = [&'a mut T; 60]

Source

type AsRef = [&'a T; 60]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 61]

Source

type AsMut = [&'a mut T; 61]

Source

type AsRef = [&'a T; 61]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 62]

Source

type AsMut = [&'a mut T; 62]

Source

type AsRef = [&'a T; 62]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 63]

Source

type AsMut = [&'a mut T; 63]

Source

type AsRef = [&'a T; 63]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 64]

Source

type AsMut = [&'a mut T; 64]

Source

type AsRef = [&'a T; 64]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 65]

Source

type AsMut = [&'a mut T; 65]

Source

type AsRef = [&'a T; 65]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 66]

Source

type AsMut = [&'a mut T; 66]

Source

type AsRef = [&'a T; 66]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 67]

Source

type AsMut = [&'a mut T; 67]

Source

type AsRef = [&'a T; 67]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 68]

Source

type AsMut = [&'a mut T; 68]

Source

type AsRef = [&'a T; 68]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 69]

Source

type AsMut = [&'a mut T; 69]

Source

type AsRef = [&'a T; 69]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 70]

Source

type AsMut = [&'a mut T; 70]

Source

type AsRef = [&'a T; 70]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 71]

Source

type AsMut = [&'a mut T; 71]

Source

type AsRef = [&'a T; 71]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 72]

Source

type AsMut = [&'a mut T; 72]

Source

type AsRef = [&'a T; 72]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 73]

Source

type AsMut = [&'a mut T; 73]

Source

type AsRef = [&'a T; 73]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 74]

Source

type AsMut = [&'a mut T; 74]

Source

type AsRef = [&'a T; 74]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 75]

Source

type AsMut = [&'a mut T; 75]

Source

type AsRef = [&'a T; 75]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 76]

Source

type AsMut = [&'a mut T; 76]

Source

type AsRef = [&'a T; 76]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 77]

Source

type AsMut = [&'a mut T; 77]

Source

type AsRef = [&'a T; 77]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 78]

Source

type AsMut = [&'a mut T; 78]

Source

type AsRef = [&'a T; 78]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 79]

Source

type AsMut = [&'a mut T; 79]

Source

type AsRef = [&'a T; 79]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 80]

Source

type AsMut = [&'a mut T; 80]

Source

type AsRef = [&'a T; 80]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 81]

Source

type AsMut = [&'a mut T; 81]

Source

type AsRef = [&'a T; 81]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 82]

Source

type AsMut = [&'a mut T; 82]

Source

type AsRef = [&'a T; 82]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 83]

Source

type AsMut = [&'a mut T; 83]

Source

type AsRef = [&'a T; 83]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 84]

Source

type AsMut = [&'a mut T; 84]

Source

type AsRef = [&'a T; 84]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 85]

Source

type AsMut = [&'a mut T; 85]

Source

type AsRef = [&'a T; 85]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 86]

Source

type AsMut = [&'a mut T; 86]

Source

type AsRef = [&'a T; 86]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 87]

Source

type AsMut = [&'a mut T; 87]

Source

type AsRef = [&'a T; 87]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 88]

Source

type AsMut = [&'a mut T; 88]

Source

type AsRef = [&'a T; 88]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 89]

Source

type AsMut = [&'a mut T; 89]

Source

type AsRef = [&'a T; 89]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 90]

Source

type AsMut = [&'a mut T; 90]

Source

type AsRef = [&'a T; 90]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 91]

Source

type AsMut = [&'a mut T; 91]

Source

type AsRef = [&'a T; 91]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 92]

Source

type AsMut = [&'a mut T; 92]

Source

type AsRef = [&'a T; 92]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 93]

Source

type AsMut = [&'a mut T; 93]

Source

type AsRef = [&'a T; 93]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 94]

Source

type AsMut = [&'a mut T; 94]

Source

type AsRef = [&'a T; 94]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 95]

Source

type AsMut = [&'a mut T; 95]

Source

type AsRef = [&'a T; 95]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 96]

Source

type AsMut = [&'a mut T; 96]

Source

type AsRef = [&'a T; 96]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 97]

Source

type AsMut = [&'a mut T; 97]

Source

type AsRef = [&'a T; 97]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 98]

Source

type AsMut = [&'a mut T; 98]

Source

type AsRef = [&'a T; 98]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 99]

Source

type AsMut = [&'a mut T; 99]

Source

type AsRef = [&'a T; 99]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 100]

Source

type AsMut = [&'a mut T; 100]

Source

type AsRef = [&'a T; 100]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 101]

Source

type AsMut = [&'a mut T; 101]

Source

type AsRef = [&'a T; 101]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 102]

Source

type AsMut = [&'a mut T; 102]

Source

type AsRef = [&'a T; 102]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 103]

Source

type AsMut = [&'a mut T; 103]

Source

type AsRef = [&'a T; 103]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 104]

Source

type AsMut = [&'a mut T; 104]

Source

type AsRef = [&'a T; 104]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 105]

Source

type AsMut = [&'a mut T; 105]

Source

type AsRef = [&'a T; 105]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 106]

Source

type AsMut = [&'a mut T; 106]

Source

type AsRef = [&'a T; 106]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 107]

Source

type AsMut = [&'a mut T; 107]

Source

type AsRef = [&'a T; 107]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 108]

Source

type AsMut = [&'a mut T; 108]

Source

type AsRef = [&'a T; 108]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 109]

Source

type AsMut = [&'a mut T; 109]

Source

type AsRef = [&'a T; 109]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 110]

Source

type AsMut = [&'a mut T; 110]

Source

type AsRef = [&'a T; 110]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 111]

Source

type AsMut = [&'a mut T; 111]

Source

type AsRef = [&'a T; 111]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 112]

Source

type AsMut = [&'a mut T; 112]

Source

type AsRef = [&'a T; 112]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 113]

Source

type AsMut = [&'a mut T; 113]

Source

type AsRef = [&'a T; 113]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 114]

Source

type AsMut = [&'a mut T; 114]

Source

type AsRef = [&'a T; 114]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 115]

Source

type AsMut = [&'a mut T; 115]

Source

type AsRef = [&'a T; 115]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 116]

Source

type AsMut = [&'a mut T; 116]

Source

type AsRef = [&'a T; 116]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 117]

Source

type AsMut = [&'a mut T; 117]

Source

type AsRef = [&'a T; 117]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 118]

Source

type AsMut = [&'a mut T; 118]

Source

type AsRef = [&'a T; 118]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 119]

Source

type AsMut = [&'a mut T; 119]

Source

type AsRef = [&'a T; 119]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 120]

Source

type AsMut = [&'a mut T; 120]

Source

type AsRef = [&'a T; 120]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 121]

Source

type AsMut = [&'a mut T; 121]

Source

type AsRef = [&'a T; 121]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 122]

Source

type AsMut = [&'a mut T; 122]

Source

type AsRef = [&'a T; 122]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 123]

Source

type AsMut = [&'a mut T; 123]

Source

type AsRef = [&'a T; 123]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 124]

Source

type AsMut = [&'a mut T; 124]

Source

type AsRef = [&'a T; 124]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 125]

Source

type AsMut = [&'a mut T; 125]

Source

type AsRef = [&'a T; 125]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 126]

Source

type AsMut = [&'a mut T; 126]

Source

type AsRef = [&'a T; 126]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 127]

Source

type AsMut = [&'a mut T; 127]

Source

type AsRef = [&'a T; 127]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 128]

Source

type AsMut = [&'a mut T; 128]

Source

type AsRef = [&'a T; 128]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 200]

Source

type AsMut = [&'a mut T; 200]

Source

type AsRef = [&'a T; 200]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 256]

Source

type AsMut = [&'a mut T; 256]

Source

type AsRef = [&'a T; 256]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 300]

Source

type AsMut = [&'a mut T; 300]

Source

type AsRef = [&'a T; 300]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 400]

Source

type AsMut = [&'a mut T; 400]

Source

type AsRef = [&'a T; 400]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 500]

Source

type AsMut = [&'a mut T; 500]

Source

type AsRef = [&'a T; 500]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 512]

Source

type AsMut = [&'a mut T; 512]

Source

type AsRef = [&'a T; 512]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 600]

Source

type AsMut = [&'a mut T; 600]

Source

type AsRef = [&'a T; 600]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 700]

Source

type AsMut = [&'a mut T; 700]

Source

type AsRef = [&'a T; 700]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 800]

Source

type AsMut = [&'a mut T; 800]

Source

type AsRef = [&'a T; 800]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 900]

Source

type AsMut = [&'a mut T; 900]

Source

type AsRef = [&'a T; 900]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 1000]

Source

type AsMut = [&'a mut T; 1000]

Source

type AsRef = [&'a T; 1000]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 1024]

Source

type AsMut = [&'a mut T; 1024]

Source

type AsRef = [&'a T; 1024]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 2048]

Source

type AsMut = [&'a mut T; 2048]

Source

type AsRef = [&'a T; 2048]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 4096]

Source

type AsMut = [&'a mut T; 4096]

Source

type AsRef = [&'a T; 4096]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 8192]

Source

type AsMut = [&'a mut T; 8192]

Source

type AsRef = [&'a T; 8192]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 16384]

Source

type AsMut = [&'a mut T; 16384]

Source

type AsRef = [&'a T; 16384]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 32768]

Source

type AsMut = [&'a mut T; 32768]

Source

type AsRef = [&'a T; 32768]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Source

impl<'a, T: 'a> ArrayAsRef<'a> for [T; 65536]

Source

type AsMut = [&'a mut T; 65536]

Source

type AsRef = [&'a T; 65536]

Source

fn as_ref_array(&'a self) -> Self::AsRef

Source

fn as_mut_array(&'a mut self) -> Self::AsMut

Implementors